<?php

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

// reference the Dompdf namespace
use Dompdf\Dompdf;

class Af_Gift_Card_Admin {

	// Constructor.
	public function __construct() {

		// Include Gift Card PDF.
		add_action( 'wp_loaded', array( $this, 'afgc_include_pdf_code_cb' ) );

		// Scripts Enqueue.
		add_action( 'admin_enqueue_scripts', array( $this, 'afgc_admin_scripts' ) );

		// Add submenu Dashboard to Woocommerce Menu.
		add_action( 'admin_menu', array( $this, 'afgc_add_dashboard_menu_item_cb' ) );

		// Include Gift Card Dashboard Files.
		add_action( 'admin_init', array( $this, 'afgc_add_dashboard_tabs_cb' ), 10 );

		// Product Select 2.
		add_action( 'wp_ajax_afgc_select_products', array( $this, 'afgc_select_products' ) );

		add_action( 'wp_ajax_nopriv_afgc_select_products', array( $this, 'afgc_select_products' ) );

		// Product Categories Select 2.
		add_action( 'wp_ajax_afgc_category_search', array( $this, 'afgc_category_search' ) );

		add_action( 'wp_ajax_nopriv_afgc_category_search', array( $this, 'afgc_category_search' ) );

		// Add meta box to Gift Card Log.
		add_action( 'add_meta_boxes', array( $this, 'afgc_add_metabox_gift_card_log_cb' ) );

		// Include Setting Files For Gift Card.
		add_action( 'woocommerce_get_settings_pages', array( $this, 'afgc_add_setting_page' ) );

		add_action( 'woocommerce_after_order_itemmeta', array( $this, 'afgc_prd_files_with_line_item' ), 10, 3 );

		// Conditionally remove duplicate submenu link.
		add_action( 'admin_menu', array( $this, 'afgc_remove_submenu_link_cb' ), 100 );

		// Render tabs of Gift Card.
		add_action( 'all_admin_notices', array( $this, 'afgc_render_tabs_cb' ), 5 );
	}


	// Scripts Enqueue.
	public function afgc_admin_scripts() {

		$screen = get_current_screen();

		if ( 'edit-afgc_gallery_cat' == $screen->id || 'edit-afgc_gift_card_log' == $screen->id || 'woocommerce_page_afgc_dashboard ' == $screen->id || 'woocommerce_page_wc-settings' == $screen->id || 'product' == $screen->id || 'woocommerce_page_afgc_dashboard' == $screen->base ) {

			wp_enqueue_style( 'afgc-admin', plugins_url( '/assets/css/afgc-admin.css', __FILE__ ), false, '1.0.0' );

			wp_enqueue_script( 'jquery' );

			wp_enqueue_media();

			wp_enqueue_script( 'afgc-admin', plugins_url( '/assets/js/afgc-admin.js', __FILE__ ), array(), '1.0.0', false );

			if ( defined( 'WC_PLUGIN_FILE' ) ) {

				wp_enqueue_style( 'wc-select2', plugins_url( 'assets/css/select2.css', WC_PLUGIN_FILE ), array(), '5.7.2' );
				wp_enqueue_script( 'wc-select2', plugins_url( 'assets/js/select2/select2.min.js', WC_PLUGIN_FILE ), array( 'jquery' ), '4.0.3', true );
			}
		}

		$addify_gift_card_ajax_data = array(

			'admin_url' => admin_url( 'admin-ajax.php' ),

			'nonce'     => wp_create_nonce( 'addify_agf_nonce' ),

		);

		wp_localize_script( 'afgc-admin', 'k_php_var', $addify_gift_card_ajax_data );
	}


	public function afgc_include_pdf_code_cb() {

		if ( isset( $_GET['download_gf_id'] ) ) {

			require_once AFGC_PLUGIN_DIR . 'vendor/autoload.php';

			ob_start();

			include_once AFGC_PLUGIN_DIR . '/admin/includes/templates/afgc-pdf-template.php';

			$temp = ob_get_clean();

			$dompdf = new Dompdf();

			$options = $dompdf->getOptions();

			$options->set( array( 'isRemoteEnabled' => true ) );

			$dompdf->setOptions( $options );

			$dompdf->loadHtml( $temp );

			$dompdf->setPaper( 'A4', 'portrait' );

			$dompdf->render();
			$afgc_pdf_file_name = get_option('afgc_pdf_file_name');

			if (!empty($afgc_pdf_file_name)) {
				$afgc_pdf_file_name = $afgc_pdf_file_name;
			} else {
				$afgc_pdf_file_name = 'document';
			}
			$dompdf->stream($afgc_pdf_file_name . '.pdf');

		}
	}

	// Add submenu Dashboard to Woocommerce Menu.
	public function afgc_add_dashboard_menu_item_cb() {

		add_submenu_page(
			'woocommerce',
			__( 'Gift Cards', 'addify_gift_cards' ),
			__( 'Gift Cards', 'addify_gift_cards' ),
			'manage_options',
			'afgc_dashboard',
			array( $this, 'afgc_gift_card_tabs_cb' ),
			10
		);
	}


	// Gift Card Sub Menu callback.
	public function afgc_gift_card_tabs_cb() {

		?>

		<div class="afgc-tabs-section">

			<form method="post" action="options.php" class="afgc_options_form">    

				<?php

				if ( isset( $_GET['page'] ) && 'afgc_dashboard' === $_GET['page'] ) {

					settings_fields( 'afgc_dashboard_fields' );

					do_settings_sections( 'afgc_dashboard_section' );

				}

				?>

			</form> 

		</div>
		
		<?php
	}


	// Include Gift Card Dashboard Files.
	public function afgc_add_dashboard_tabs_cb() {

		include_once AFGC_PLUGIN_DIR . '/admin/includes/templates/afgc-dashboard-temp.php';
	}


	// Conditionally remove duplicate submenu link.
	public function afgc_remove_submenu_link_cb() {

		global $pagenow, $typenow;

		if ( ( 'admin.php' === $pagenow && isset( $_GET['page'] ) && 'afgc_dashboard' === sanitize_text_field( wp_unslash( $_GET['page'] ) ) ) ) {

			remove_submenu_page( 'woocommerce', 'edit.php?post_type=afgc_gift_card_log' );

		} elseif ( ( 'edit.php' === $pagenow && 'afgc_gift_card_log' === $typenow ) || ( 'post.php' === $pagenow && isset( $_GET['post'] ) && 'afgc_gift_card_log' === get_post_type( sanitize_text_field( wp_unslash( $_GET['post'] ) ) ) ) ) {

			remove_submenu_page( 'woocommerce', 'afgc_dashboard' );

		} else {

			remove_submenu_page( 'woocommerce', 'edit.php?post_type=afgc_gift_card_log' );

		}
	}


	// Render tabs of Gift Card.
	public function afgc_render_tabs_cb() {

		global $post, $typenow;

		$screen = get_current_screen();

		if ( $screen && in_array( $screen->id, $this->get_tab_screen_ids(), true ) ) {

			$tabs = apply_filters(
				'afgc_admin_tabs',
				array(

					'dashboard'         => array(

						'title' => __( 'Dashboard', 'addify_gift_cards' ),

						'url'   => admin_url( 'admin.php?page=afgc_dashboard' ),

					),
					'logs'              => array(

						'title' => __( 'Gift Card Logs', 'addify_gift_cards' ),

						'url'   => admin_url( 'edit.php?post_type=afgc_gift_card_log' ),
					),
					'afgc_card_gallery' => array(

						'title' => __( 'Gift Card Gallery', 'addify_gift_cards' ),

						'url'   => admin_url( 'edit-tags.php?taxonomy=afgc_gallery_cat&post_type=product' ),
					),

				)
			);

			if ( is_array( $tabs ) ) {
				?>

				<div class="wrap woocommerce">

					<h2 class="nav-tab-wrapper woo-nav-tab-wrapper">

						<?php

						$current_tab = $this->get_current_tab();

						foreach ( $tabs as $id => $tab_data ) {

							$class = $id === $current_tab ? array( 'nav-tab', 'nav-tab-active' ) : array( 'nav-tab' );

							printf( '<a href="%1$s" class="%2$s">%3$s</a>', esc_url( $tab_data['url'] ), implode( ' ', array_map( 'sanitize_html_class', $class ) ), esc_html( $tab_data['title'] ) );

						}

						?>

					</h2>

				</div>

				<?php

			}
		}
	}


	// Get Current Tab.
	public function get_current_tab() {

		$screen = get_current_screen();

		$tabs_screens = array(
			'afgc_gift_card_log',
			'edit-afgc_gift_card_log',
			'woocommerce_page_afgc_dashboard',
			'afgc_gallery_cat',
			'edit_afgc_gallery_cat',
		);

		switch ( $screen->id ) {

			case 'afgc_gift_card_log':
			case 'edit-afgc_gift_card_log':
				return 'logs';

			case 'woocommerce_page_afgc_dashboard':
				return 'dashboard';

			case 'afgc_gallery_cat':
			case 'edit-afgc_gallery_cat':
				return 'afgc_card_gallery';

		}
	}


	public function get_tab_screen_ids() {

		$tabs_screens = array(
			'woocommerce_page_afgc_dashboard',
			'afgc_gift_card_log',
			'edit-afgc_gift_card_log',
			'afgc_gallery_cat',
			'edit-afgc_gallery_cat',
		);

		return $tabs_screens;
	}


	public function afgc_add_setting_page( $settings ) {

		$settings[] = include_once AFGC_PLUGIN_DIR . '/admin/includes/settings/class-af-gift-card-settings-tab.php';

		return $settings;
	}


	// Select Product Select 2.
	public function afgc_select_products() {

		if ( isset( $_POST['nonce'] ) && '' != $_POST['nonce'] ) {

			$nonce = sanitize_text_field( wp_unslash( $_POST['nonce'] ) );

		} else {

			$nonce = 0;

		}

		if ( isset( $_POST['q'] ) && '' != $_POST['q'] ) {

			if ( ! wp_verify_nonce( $nonce, 'addify_agf_nonce' ) ) {

				die( 'Failed ajax security check!' );

			}

			$pro = sanitize_text_field( wp_unslash( $_POST['q'] ) );

		} else {

			$pro = '';

		}

		$data_array = array();

		$args = array(
			'post_type'   => 'product',

			'post_status' => 'publish',

			'numberposts' => 50,

			's'           => $pro,

		);

		$pros = get_posts( $args );

		if ( ! empty( $pros ) ) {

			foreach ( $pros as $proo ) {

				$title = ( mb_strlen( $proo->post_title ) > 50 ) ? mb_substr( $proo->post_title, 0, 49 ) . '...' : $proo->post_title;

				$data_array[] = array( $proo->ID, $title );

			}
		}

		echo wp_json_encode( $data_array );

		die();
	}



	// Product Categories Select 2.
	public function afgc_category_search() {

		$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : 0;

		if ( isset( $_POST['nonce'] ) && ! wp_verify_nonce( $nonce, 'addify_agf_nonce' ) ) {

			die( 'Failed Ajax security check!' );

		}

		$s = isset( $_POST['q'] ) ? sanitize_text_field( wp_unslash( $_POST['q'] ) ) : '';

		$args = array(

			'taxonomy'   => 'product_cat',

			'hide_empty' => false,

			'name__like' => $s,

		);

		$categories = get_terms( $args );

		$data_array = array();

		if ( ! empty( $categories ) ) {

			foreach ( $categories as $category ) {

				$title = ( mb_strlen( $category->name ) > 50 ) ? mb_substr( $category->name, 0, 49 ) . '...' : $category->name;

				$data_array[] = array( $category->term_id, $title );

			}
		}

		wp_send_json( $data_array );

		die();
	}



	public function afgc_prd_files_with_line_item( $item_id, $item, $product ) {

		$meta_data = $item->get_meta_data();

		foreach ( $meta_data as $meta ) {

			$data = $meta->get_data();

			if ( ! empty( $data ) && 'afgc_gift_card_infos' === $data['key'] ) {

				if ( ! empty( $array_of_card_info['total_recipient_user_Select'] ) ) {

					$total_field = $array_of_card_info['total_recipient_user_Select'];

				} else {

					$total_field = -1;

				}

				$array_of_card_info = $data['value'];

				?>

				<ul style="list-style: none; margin:5px 0px;">
					<?php if ( ! empty( $array_of_card_info['afgc_sender_name'] ) ) { ?>

						<li><label><?php echo esc_html__( 'Sender Name : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $array_of_card_info['afgc_sender_name'] ); ?></li>	

					<?php } ?>
					
					<?php if ( ! empty( $array_of_card_info['afgc_sender_message'] ) ) { ?>

						<li><label><?php echo esc_html__( 'Sender Message : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $array_of_card_info['afgc_sender_message'] ); ?></li>	

						<?php
					}

					for ( $i = 0; $i <= $total_field; $i++ ) {

						if ( ! empty( $array_of_card_info[ 'afgc_recipient_name' . $i ] ) ) {
							?>

							<li><label><?php echo esc_html__( 'Recipient Name : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $array_of_card_info[ 'afgc_recipient_name' . $i ] ); ?></li>	

						<?php } ?>

						<?php if ( ! empty( $array_of_card_info[ 'afgc_recipient_email' . $i ] ) ) { ?>

							<li><label><?php echo esc_html__( 'Recipient Email : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $array_of_card_info[ 'afgc_recipient_email' . $i ] ); ?></li>		

							<?php
						}
					}

					if ( ! empty( $array_of_card_info['afgc_delivery_date'] ) ) {
						?>

						<li><label><?php echo esc_html__( 'Delivery Date : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $array_of_card_info['afgc_delivery_date'] ); ?></li>		

					<?php } ?>

					<?php if ( ! empty( $array_of_card_info['afgc_price_of_gift_card'] ) ) { ?>

						<li><label><?php echo esc_html__( ' Price : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $array_of_card_info['afgc_price_of_gift_card'] ); ?></li>

					<?php } ?>

					<?php
					if ( ! empty( $array_of_card_info['afgc_gift_products'] ) ) {
			$product = wc_get_product($array_of_card_info['afgc_gift_products']);
			$product_name = $product->get_name();
						?>

						<li><label><?php echo esc_html__( ' Product Gift : ', 'addify_gift_cards' ); ?></label><?php echo esc_attr( $product_name ); ?></li>

					<?php } ?>


				</ul>

				<?php

			}
		}
	}


	// Custom Meta Box For Gift Card Details.
	public function afgc_add_metabox_gift_card_log_cb() {

		add_meta_box(
			'afgc_gift_card_details',
			esc_html__( 'Gift Card', 'addify_gift_cards' ),
			array( $this, 'afgc_gift_card_details_cb' ),
			'afgc_gift_card_log'
		);
	}

	public function afgc_gift_card_details_cb() {

		include_once AFGC_PLUGIN_DIR . '/admin/includes/meta-boxes/afgc-gift-card-info.php';
	}
}

new Af_Gift_Card_Admin();
